# Tutorials

📜 *Extensive user guide, mostly based on step-by-step tutorials ...*

All tutorials are written in jupyter notebooks, that can be :

- read using the [online documentation](https://qmat.readthedocs.io/en/latest/notebooks.html)
- downloaded from the [notebook folder](https://github.com/Parallel-in-Time/qmat/tree/main/docs/notebooks) and played with 

> 🛠️ Basic usage tutorials are finalized and polished, the rest is still in construction ... 

Notebooks are categorized into three main sections :

1. **Basic usage** : how to generate and use basic $Q$-coefficients and $Q_\Delta$ approximations
2. **Extended usage** : additional features or `qmat`, like $S$-matrix, `hCoeffs`, `dTau`, etc ...
3. **Advanced usage** : using `qmat` for generic non-linear ODE, multilevel SDC, PFASST, ...


```{eval-rst}
Basic usage
===========

.. toctree::
    :maxdepth: 1
    :glob:

    notebooks/0*

Extended usage
==============

.. toctree::
    :maxdepth: 1
    :glob:

    notebooks/1*

Advanced usage
==============

.. toctree::
    :maxdepth: 1
    :glob:

    notebooks/2*
```
